@@ -1,6 +1,6 @@
 package Tie::DiskUsage;
 
-$VERSION = '0.09';
+$VERSION = '0.1';
 @ISA = qw(Tie::StdHash);
 
 use strict;
@@ -8,22 +8,29 @@ use vars qw($DU_BIN);
 use Carp 'croak';
 use Tie::Hash;
 
+
 $DU_BIN = '/usr/bin/du';
 
+
 sub TIEHASH { 
-    my $class = shift;
-    return bless &_tie, $class;
+    my $pkg = shift;
+     
+    return bless( &_tie, $pkg );
 }
 
+sub UNTIE {}
+
 sub _tie {
     _locate_du();
-    &_parse_usage;
+    
+    return &_parse_usage;
 }
 
 sub _locate_du {
-    if ((!-e $DU_BIN || !-f $DU_BIN) && $] >= 5.008) { 
+    if (not (-e $DU_BIN && -f $DU_BIN) && $] >= 5.008) { 
         require File::Which;
-	my $du_which = File::Which::which('du') || '';
+	my $du_which = File::Which::which('du');
+	
 	$du_which 
 	  ? $DU_BIN = $du_which 
 	  : croak "Couldn't locate $DU_BIN: $!";
@@ -32,16 +39,21 @@ sub _locate_du {
 
 sub _parse_usage {
     my $path = shift || '.';
+    
+    my %usage;
+    
     local *PIPE;
     open PIPE, "$DU_BIN @_ $path |" or exit 1;
-    my %usage;
     {
-         local($/, $_);
-         $/ = ''; $_ = <PIPE>;
+         local ($/, $_); 
+	 $/ = '';
+	  
+	 $_ = <PIPE>;
          %usage = (reverse split);
     }
     close PIPE 
       or croak "Couldn't drop pipe to $DU_BIN: $!";
+      
     return \%usage;
 } 
 
@@ -68,7 +80,7 @@ the du-command on is being omitted, the current working
 directory will be examined; optional arguments to C<du> may be 
 passed subsequently.
 
-By default the location of the du-command is to be
+By default, the location of the du-command is to be
 assumed in F</usr/bin/du>; if C<du> cannot be found to exist
 there, C<File::Which> will attempt to gather its former location.
 
